==> spark-3.5.8.tgz: spark-3.5.8/sql/core/src/test/scala/org/apache/spark/sql/execution/command/v2/AlterTableRecoverPartitionsSuite.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.spark.sql.execution.command.v2

import org.apache.spark.sql.AnalysisException
import org.apache.spark.sql.execution.command

/**
 * The class contains tests for the `ALTER TABLE .. RECOVER PARTITIONS` command
 * to check V2 table catalogs.
 */
class AlterTableRecoverPartitionsSuite
  extends command.AlterTableRecoverPartitionsSuiteBase
  with CommandSuiteBase {

  test("partition recovering of v2 tables is not supported") {
    withNamespaceAndTable("ns", "tbl") { t =>
      spark.sql(s"CREATE TABLE $t (id bigint, data string) $defaultUsing")
      checkError(
        exception = intercept[AnalysisException] {
          sql(s"ALTER TABLE $t RECOVER PARTITIONS")
        },
        errorClass = "NOT_SUPPORTED_COMMAND_FOR_V2_TABLE",
        parameters = Map("cmd" -> "ALTER TABLE ... RECOVER PARTITIONS")
      )
    }
  }
}

==> spark-4.1.1.tgz: spark-4.1.1/sql/core/src/test/scala/org/apache/spark/sql/execution/command/v2/AlterTableRecoverPartitionsSuite.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.spark.sql.execution.command.v2

import org.apache.spark.sql.AnalysisException
import org.apache.spark.sql.execution.command

/**
 * The class contains tests for the `ALTER TABLE .. RECOVER PARTITIONS` command
 * to check V2 table catalogs.
 */
class AlterTableRecoverPartitionsSuite
  extends command.AlterTableRecoverPartitionsSuiteBase
  with CommandSuiteBase {

  test("partition recovering of v2 tables is not supported") {
    withNamespaceAndTable("ns", "tbl") { t =>
      spark.sql(s"CREATE TABLE $t (id bigint, data string) $defaultUsing")
      checkError(
        exception = intercept[AnalysisException] {
          sql(s"ALTER TABLE $t RECOVER PARTITIONS")
        },
        condition = "NOT_SUPPORTED_COMMAND_FOR_V2_TABLE",
        parameters = Map("cmd" -> "ALTER TABLE ... RECOVER PARTITIONS")
      )
    }
  }
}
